# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TeamRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'gid': 'str',
        'resource_type': 'str',
        'name': 'str',
        'description': 'str',
        'html_description': 'str',
        'organization': 'str',
        'visibility': 'str',
        'edit_team_name_or_description_access_level': 'str',
        'edit_team_visibility_or_trash_team_access_level': 'str',
        'member_invite_management_access_level': 'str',
        'guest_invite_management_access_level': 'str',
        'join_request_management_access_level': 'str',
        'team_member_removal_access_level': 'str'
    }

    attribute_map = {
        'gid': 'gid',
        'resource_type': 'resource_type',
        'name': 'name',
        'description': 'description',
        'html_description': 'html_description',
        'organization': 'organization',
        'visibility': 'visibility',
        'edit_team_name_or_description_access_level': 'edit_team_name_or_description_access_level',
        'edit_team_visibility_or_trash_team_access_level': 'edit_team_visibility_or_trash_team_access_level',
        'member_invite_management_access_level': 'member_invite_management_access_level',
        'guest_invite_management_access_level': 'guest_invite_management_access_level',
        'join_request_management_access_level': 'join_request_management_access_level',
        'team_member_removal_access_level': 'team_member_removal_access_level'
    }

    def __init__(self, gid=None, resource_type=None, name=None, description=None, html_description=None, organization=None, visibility=None, edit_team_name_or_description_access_level=None, edit_team_visibility_or_trash_team_access_level=None, member_invite_management_access_level=None, guest_invite_management_access_level=None, join_request_management_access_level=None, team_member_removal_access_level=None):  # noqa: E501
        """TeamRequest - a model defined in Swagger"""  # noqa: E501
        self._gid = None
        self._resource_type = None
        self._name = None
        self._description = None
        self._html_description = None
        self._organization = None
        self._visibility = None
        self._edit_team_name_or_description_access_level = None
        self._edit_team_visibility_or_trash_team_access_level = None
        self._member_invite_management_access_level = None
        self._guest_invite_management_access_level = None
        self._join_request_management_access_level = None
        self._team_member_removal_access_level = None
        self.discriminator = None
        if gid is not None:
            self.gid = gid
        if resource_type is not None:
            self.resource_type = resource_type
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if html_description is not None:
            self.html_description = html_description
        if organization is not None:
            self.organization = organization
        if visibility is not None:
            self.visibility = visibility
        if edit_team_name_or_description_access_level is not None:
            self.edit_team_name_or_description_access_level = edit_team_name_or_description_access_level
        if edit_team_visibility_or_trash_team_access_level is not None:
            self.edit_team_visibility_or_trash_team_access_level = edit_team_visibility_or_trash_team_access_level
        if member_invite_management_access_level is not None:
            self.member_invite_management_access_level = member_invite_management_access_level
        if guest_invite_management_access_level is not None:
            self.guest_invite_management_access_level = guest_invite_management_access_level
        if join_request_management_access_level is not None:
            self.join_request_management_access_level = join_request_management_access_level
        if team_member_removal_access_level is not None:
            self.team_member_removal_access_level = team_member_removal_access_level

    @property
    def gid(self):
        """Gets the gid of this TeamRequest.  # noqa: E501

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :return: The gid of this TeamRequest.  # noqa: E501
        :rtype: str
        """
        return self._gid

    @gid.setter
    def gid(self, gid):
        """Sets the gid of this TeamRequest.

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :param gid: The gid of this TeamRequest.  # noqa: E501
        :type: str
        """

        self._gid = gid

    @property
    def resource_type(self):
        """Gets the resource_type of this TeamRequest.  # noqa: E501

        The base type of this resource.  # noqa: E501

        :return: The resource_type of this TeamRequest.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this TeamRequest.

        The base type of this resource.  # noqa: E501

        :param resource_type: The resource_type of this TeamRequest.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def name(self):
        """Gets the name of this TeamRequest.  # noqa: E501

        The name of the team.  # noqa: E501

        :return: The name of this TeamRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TeamRequest.

        The name of the team.  # noqa: E501

        :param name: The name of this TeamRequest.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this TeamRequest.  # noqa: E501

        The description of the team.   # noqa: E501

        :return: The description of this TeamRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this TeamRequest.

        The description of the team.   # noqa: E501

        :param description: The description of this TeamRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def html_description(self):
        """Gets the html_description of this TeamRequest.  # noqa: E501

        The description of the team with formatting as HTML.   # noqa: E501

        :return: The html_description of this TeamRequest.  # noqa: E501
        :rtype: str
        """
        return self._html_description

    @html_description.setter
    def html_description(self, html_description):
        """Sets the html_description of this TeamRequest.

        The description of the team with formatting as HTML.   # noqa: E501

        :param html_description: The html_description of this TeamRequest.  # noqa: E501
        :type: str
        """

        self._html_description = html_description

    @property
    def organization(self):
        """Gets the organization of this TeamRequest.  # noqa: E501

        The organization/workspace the team belongs to. This must be the same organization you are in and cannot be changed once set.   # noqa: E501

        :return: The organization of this TeamRequest.  # noqa: E501
        :rtype: str
        """
        return self._organization

    @organization.setter
    def organization(self, organization):
        """Sets the organization of this TeamRequest.

        The organization/workspace the team belongs to. This must be the same organization you are in and cannot be changed once set.   # noqa: E501

        :param organization: The organization of this TeamRequest.  # noqa: E501
        :type: str
        """

        self._organization = organization

    @property
    def visibility(self):
        """Gets the visibility of this TeamRequest.  # noqa: E501

        The visibility of the team to users in the same organization   # noqa: E501

        :return: The visibility of this TeamRequest.  # noqa: E501
        :rtype: str
        """
        return self._visibility

    @visibility.setter
    def visibility(self, visibility):
        """Sets the visibility of this TeamRequest.

        The visibility of the team to users in the same organization   # noqa: E501

        :param visibility: The visibility of this TeamRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["secret", "request_to_join", "public"]  # noqa: E501
        if visibility not in allowed_values:
            raise ValueError(
                "Invalid value for `visibility` ({0}), must be one of {1}"  # noqa: E501
                .format(visibility, allowed_values)
            )

        self._visibility = visibility

    @property
    def edit_team_name_or_description_access_level(self):
        """Gets the edit_team_name_or_description_access_level of this TeamRequest.  # noqa: E501

        Controls who can edit team name and description   # noqa: E501

        :return: The edit_team_name_or_description_access_level of this TeamRequest.  # noqa: E501
        :rtype: str
        """
        return self._edit_team_name_or_description_access_level

    @edit_team_name_or_description_access_level.setter
    def edit_team_name_or_description_access_level(self, edit_team_name_or_description_access_level):
        """Sets the edit_team_name_or_description_access_level of this TeamRequest.

        Controls who can edit team name and description   # noqa: E501

        :param edit_team_name_or_description_access_level: The edit_team_name_or_description_access_level of this TeamRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["all_team_members", "only_team_admins"]  # noqa: E501
        if edit_team_name_or_description_access_level not in allowed_values:
            raise ValueError(
                "Invalid value for `edit_team_name_or_description_access_level` ({0}), must be one of {1}"  # noqa: E501
                .format(edit_team_name_or_description_access_level, allowed_values)
            )

        self._edit_team_name_or_description_access_level = edit_team_name_or_description_access_level

    @property
    def edit_team_visibility_or_trash_team_access_level(self):
        """Gets the edit_team_visibility_or_trash_team_access_level of this TeamRequest.  # noqa: E501

        Controls who can edit team visibility and trash teams   # noqa: E501

        :return: The edit_team_visibility_or_trash_team_access_level of this TeamRequest.  # noqa: E501
        :rtype: str
        """
        return self._edit_team_visibility_or_trash_team_access_level

    @edit_team_visibility_or_trash_team_access_level.setter
    def edit_team_visibility_or_trash_team_access_level(self, edit_team_visibility_or_trash_team_access_level):
        """Sets the edit_team_visibility_or_trash_team_access_level of this TeamRequest.

        Controls who can edit team visibility and trash teams   # noqa: E501

        :param edit_team_visibility_or_trash_team_access_level: The edit_team_visibility_or_trash_team_access_level of this TeamRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["all_team_members", "only_team_admins"]  # noqa: E501
        if edit_team_visibility_or_trash_team_access_level not in allowed_values:
            raise ValueError(
                "Invalid value for `edit_team_visibility_or_trash_team_access_level` ({0}), must be one of {1}"  # noqa: E501
                .format(edit_team_visibility_or_trash_team_access_level, allowed_values)
            )

        self._edit_team_visibility_or_trash_team_access_level = edit_team_visibility_or_trash_team_access_level

    @property
    def member_invite_management_access_level(self):
        """Gets the member_invite_management_access_level of this TeamRequest.  # noqa: E501

        Controls who can accept or deny member invites for a given team   # noqa: E501

        :return: The member_invite_management_access_level of this TeamRequest.  # noqa: E501
        :rtype: str
        """
        return self._member_invite_management_access_level

    @member_invite_management_access_level.setter
    def member_invite_management_access_level(self, member_invite_management_access_level):
        """Sets the member_invite_management_access_level of this TeamRequest.

        Controls who can accept or deny member invites for a given team   # noqa: E501

        :param member_invite_management_access_level: The member_invite_management_access_level of this TeamRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["all_team_members", "only_team_admins"]  # noqa: E501
        if member_invite_management_access_level not in allowed_values:
            raise ValueError(
                "Invalid value for `member_invite_management_access_level` ({0}), must be one of {1}"  # noqa: E501
                .format(member_invite_management_access_level, allowed_values)
            )

        self._member_invite_management_access_level = member_invite_management_access_level

    @property
    def guest_invite_management_access_level(self):
        """Gets the guest_invite_management_access_level of this TeamRequest.  # noqa: E501

        Controls who can accept or deny guest invites for a given team   # noqa: E501

        :return: The guest_invite_management_access_level of this TeamRequest.  # noqa: E501
        :rtype: str
        """
        return self._guest_invite_management_access_level

    @guest_invite_management_access_level.setter
    def guest_invite_management_access_level(self, guest_invite_management_access_level):
        """Sets the guest_invite_management_access_level of this TeamRequest.

        Controls who can accept or deny guest invites for a given team   # noqa: E501

        :param guest_invite_management_access_level: The guest_invite_management_access_level of this TeamRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["all_team_members", "only_team_admins"]  # noqa: E501
        if guest_invite_management_access_level not in allowed_values:
            raise ValueError(
                "Invalid value for `guest_invite_management_access_level` ({0}), must be one of {1}"  # noqa: E501
                .format(guest_invite_management_access_level, allowed_values)
            )

        self._guest_invite_management_access_level = guest_invite_management_access_level

    @property
    def join_request_management_access_level(self):
        """Gets the join_request_management_access_level of this TeamRequest.  # noqa: E501

        Controls who can accept or deny join team requests for a Membership by Request team   # noqa: E501

        :return: The join_request_management_access_level of this TeamRequest.  # noqa: E501
        :rtype: str
        """
        return self._join_request_management_access_level

    @join_request_management_access_level.setter
    def join_request_management_access_level(self, join_request_management_access_level):
        """Sets the join_request_management_access_level of this TeamRequest.

        Controls who can accept or deny join team requests for a Membership by Request team   # noqa: E501

        :param join_request_management_access_level: The join_request_management_access_level of this TeamRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["all_team_members", "only_team_admins"]  # noqa: E501
        if join_request_management_access_level not in allowed_values:
            raise ValueError(
                "Invalid value for `join_request_management_access_level` ({0}), must be one of {1}"  # noqa: E501
                .format(join_request_management_access_level, allowed_values)
            )

        self._join_request_management_access_level = join_request_management_access_level

    @property
    def team_member_removal_access_level(self):
        """Gets the team_member_removal_access_level of this TeamRequest.  # noqa: E501

        Controls who can remove team members   # noqa: E501

        :return: The team_member_removal_access_level of this TeamRequest.  # noqa: E501
        :rtype: str
        """
        return self._team_member_removal_access_level

    @team_member_removal_access_level.setter
    def team_member_removal_access_level(self, team_member_removal_access_level):
        """Sets the team_member_removal_access_level of this TeamRequest.

        Controls who can remove team members   # noqa: E501

        :param team_member_removal_access_level: The team_member_removal_access_level of this TeamRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["all_team_members", "only_team_admins"]  # noqa: E501
        if team_member_removal_access_level not in allowed_values:
            raise ValueError(
                "Invalid value for `team_member_removal_access_level` ({0}), must be one of {1}"  # noqa: E501
                .format(team_member_removal_access_level, allowed_values)
            )

        self._team_member_removal_access_level = team_member_removal_access_level

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TeamRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TeamRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class WorkspaceMembershipResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'gid': 'str',
        'resource_type': 'str',
        'user': 'CustomFieldResponsePeopleValue',
        'workspace': 'GoalResponseWorkspace',
        'user_task_list': 'WorkspaceMembershipResponseUserTaskList',
        'is_active': 'bool',
        'is_admin': 'bool',
        'is_guest': 'bool',
        'vacation_dates': 'WorkspaceMembershipResponseVacationDates',
        'created_at': 'datetime'
    }

    attribute_map = {
        'gid': 'gid',
        'resource_type': 'resource_type',
        'user': 'user',
        'workspace': 'workspace',
        'user_task_list': 'user_task_list',
        'is_active': 'is_active',
        'is_admin': 'is_admin',
        'is_guest': 'is_guest',
        'vacation_dates': 'vacation_dates',
        'created_at': 'created_at'
    }

    def __init__(self, gid=None, resource_type=None, user=None, workspace=None, user_task_list=None, is_active=None, is_admin=None, is_guest=None, vacation_dates=None, created_at=None):  # noqa: E501
        """WorkspaceMembershipResponse - a model defined in Swagger"""  # noqa: E501
        self._gid = None
        self._resource_type = None
        self._user = None
        self._workspace = None
        self._user_task_list = None
        self._is_active = None
        self._is_admin = None
        self._is_guest = None
        self._vacation_dates = None
        self._created_at = None
        self.discriminator = None
        if gid is not None:
            self.gid = gid
        if resource_type is not None:
            self.resource_type = resource_type
        if user is not None:
            self.user = user
        if workspace is not None:
            self.workspace = workspace
        if user_task_list is not None:
            self.user_task_list = user_task_list
        if is_active is not None:
            self.is_active = is_active
        if is_admin is not None:
            self.is_admin = is_admin
        if is_guest is not None:
            self.is_guest = is_guest
        if vacation_dates is not None:
            self.vacation_dates = vacation_dates
        if created_at is not None:
            self.created_at = created_at

    @property
    def gid(self):
        """Gets the gid of this WorkspaceMembershipResponse.  # noqa: E501

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :return: The gid of this WorkspaceMembershipResponse.  # noqa: E501
        :rtype: str
        """
        return self._gid

    @gid.setter
    def gid(self, gid):
        """Sets the gid of this WorkspaceMembershipResponse.

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :param gid: The gid of this WorkspaceMembershipResponse.  # noqa: E501
        :type: str
        """

        self._gid = gid

    @property
    def resource_type(self):
        """Gets the resource_type of this WorkspaceMembershipResponse.  # noqa: E501

        The base type of this resource.  # noqa: E501

        :return: The resource_type of this WorkspaceMembershipResponse.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this WorkspaceMembershipResponse.

        The base type of this resource.  # noqa: E501

        :param resource_type: The resource_type of this WorkspaceMembershipResponse.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def user(self):
        """Gets the user of this WorkspaceMembershipResponse.  # noqa: E501


        :return: The user of this WorkspaceMembershipResponse.  # noqa: E501
        :rtype: CustomFieldResponsePeopleValue
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this WorkspaceMembershipResponse.


        :param user: The user of this WorkspaceMembershipResponse.  # noqa: E501
        :type: CustomFieldResponsePeopleValue
        """

        self._user = user

    @property
    def workspace(self):
        """Gets the workspace of this WorkspaceMembershipResponse.  # noqa: E501


        :return: The workspace of this WorkspaceMembershipResponse.  # noqa: E501
        :rtype: GoalResponseWorkspace
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        """Sets the workspace of this WorkspaceMembershipResponse.


        :param workspace: The workspace of this WorkspaceMembershipResponse.  # noqa: E501
        :type: GoalResponseWorkspace
        """

        self._workspace = workspace

    @property
    def user_task_list(self):
        """Gets the user_task_list of this WorkspaceMembershipResponse.  # noqa: E501


        :return: The user_task_list of this WorkspaceMembershipResponse.  # noqa: E501
        :rtype: WorkspaceMembershipResponseUserTaskList
        """
        return self._user_task_list

    @user_task_list.setter
    def user_task_list(self, user_task_list):
        """Sets the user_task_list of this WorkspaceMembershipResponse.


        :param user_task_list: The user_task_list of this WorkspaceMembershipResponse.  # noqa: E501
        :type: WorkspaceMembershipResponseUserTaskList
        """

        self._user_task_list = user_task_list

    @property
    def is_active(self):
        """Gets the is_active of this WorkspaceMembershipResponse.  # noqa: E501

        Reflects if this user still a member of the workspace.  # noqa: E501

        :return: The is_active of this WorkspaceMembershipResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_active

    @is_active.setter
    def is_active(self, is_active):
        """Sets the is_active of this WorkspaceMembershipResponse.

        Reflects if this user still a member of the workspace.  # noqa: E501

        :param is_active: The is_active of this WorkspaceMembershipResponse.  # noqa: E501
        :type: bool
        """

        self._is_active = is_active

    @property
    def is_admin(self):
        """Gets the is_admin of this WorkspaceMembershipResponse.  # noqa: E501

        Reflects if this user is an admin of the workspace.  # noqa: E501

        :return: The is_admin of this WorkspaceMembershipResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_admin

    @is_admin.setter
    def is_admin(self, is_admin):
        """Sets the is_admin of this WorkspaceMembershipResponse.

        Reflects if this user is an admin of the workspace.  # noqa: E501

        :param is_admin: The is_admin of this WorkspaceMembershipResponse.  # noqa: E501
        :type: bool
        """

        self._is_admin = is_admin

    @property
    def is_guest(self):
        """Gets the is_guest of this WorkspaceMembershipResponse.  # noqa: E501

        Reflects if this user is a guest of the workspace.  # noqa: E501

        :return: The is_guest of this WorkspaceMembershipResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_guest

    @is_guest.setter
    def is_guest(self, is_guest):
        """Sets the is_guest of this WorkspaceMembershipResponse.

        Reflects if this user is a guest of the workspace.  # noqa: E501

        :param is_guest: The is_guest of this WorkspaceMembershipResponse.  # noqa: E501
        :type: bool
        """

        self._is_guest = is_guest

    @property
    def vacation_dates(self):
        """Gets the vacation_dates of this WorkspaceMembershipResponse.  # noqa: E501


        :return: The vacation_dates of this WorkspaceMembershipResponse.  # noqa: E501
        :rtype: WorkspaceMembershipResponseVacationDates
        """
        return self._vacation_dates

    @vacation_dates.setter
    def vacation_dates(self, vacation_dates):
        """Sets the vacation_dates of this WorkspaceMembershipResponse.


        :param vacation_dates: The vacation_dates of this WorkspaceMembershipResponse.  # noqa: E501
        :type: WorkspaceMembershipResponseVacationDates
        """

        self._vacation_dates = vacation_dates

    @property
    def created_at(self):
        """Gets the created_at of this WorkspaceMembershipResponse.  # noqa: E501

        The time at which this resource was created.  # noqa: E501

        :return: The created_at of this WorkspaceMembershipResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this WorkspaceMembershipResponse.

        The time at which this resource was created.  # noqa: E501

        :param created_at: The created_at of this WorkspaceMembershipResponse.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WorkspaceMembershipResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkspaceMembershipResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from asana.api_client import ApiClient


class UsersApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_favorites_for_user(self, user_gid, resource_type, workspace, **kwargs):  # noqa: E501
        """Get a user's favorites  # noqa: E501

        Returns all of a user's favorites in the given workspace, of the given type. Results are given in order (The same order as Asana's sidebar).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_favorites_for_user(user_gid, resource_type, workspace, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_gid: A string identifying a user. This can either be the string \"me\", an email, or the gid of a user. (required)
        :param str resource_type: The resource type of favorites to be returned. (required)
        :param str workspace: The workspace in which to get favorites. (required)
        :param int limit: Results per page. The number of objects to return per page. The value must be between 1 and 100.
        :param str offset: Offset token. An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results. 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: AsanaNamedResourceArray
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = kwargs.get("_return_http_data_only", True)
        if kwargs.get('async_req'):
            return self.get_favorites_for_user_with_http_info(user_gid, resource_type, workspace, **kwargs)  # noqa: E501
        else:
            (data) = self.get_favorites_for_user_with_http_info(user_gid, resource_type, workspace, **kwargs)  # noqa: E501
            return data

    def get_favorites_for_user_with_http_info(self, user_gid, resource_type, workspace, **kwargs):  # noqa: E501
        """Get a user's favorites  # noqa: E501

        Returns all of a user's favorites in the given workspace, of the given type. Results are given in order (The same order as Asana's sidebar).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_favorites_for_user_with_http_info(user_gid, resource_type, workspace, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_gid: A string identifying a user. This can either be the string \"me\", an email, or the gid of a user. (required)
        :param str resource_type: The resource type of favorites to be returned. (required)
        :param str workspace: The workspace in which to get favorites. (required)
        :param int limit: Results per page. The number of objects to return per page. The value must be between 1 and 100.
        :param str offset: Offset token. An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results. 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: AsanaNamedResourceArray
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_gid', 'resource_type', 'workspace', 'limit', 'offset', 'opt_fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('header_params')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_favorites_for_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_gid' is set
        if ('user_gid' not in params or
                params['user_gid'] is None):
            raise ValueError("Missing the required parameter `user_gid` when calling `get_favorites_for_user`")  # noqa: E501
        # verify the required parameter 'resource_type' is set
        if ('resource_type' not in params or
                params['resource_type'] is None):
            raise ValueError("Missing the required parameter `resource_type` when calling `get_favorites_for_user`")  # noqa: E501
        # verify the required parameter 'workspace' is set
        if ('workspace' not in params or
                params['workspace'] is None):
            raise ValueError("Missing the required parameter `workspace` when calling `get_favorites_for_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_gid' in params:
            path_params['user_gid'] = params['user_gid']  # noqa: E501

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'resource_type' in params:
            query_params.append(('resource_type', params['resource_type']))  # noqa: E501
        if 'workspace' in params:
            query_params.append(('workspace', params['workspace']))  # noqa: E501
        if 'opt_fields' in params:
            query_params.append(('opt_fields', params['opt_fields']))  # noqa: E501
            collection_formats['opt_fields'] = 'csv'  # noqa: E501

        header_params = kwargs.get("header_params", {})

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/users/{user_gid}/favorites', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AsanaNamedResourceArray',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_user(self, user_gid, **kwargs):  # noqa: E501
        """Get a user  # noqa: E501

        Returns the full user record for the single user with the provided ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user(user_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_gid: A string identifying a user. This can either be the string \"me\", an email, or the gid of a user. (required)
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: UserResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = kwargs.get("_return_http_data_only", True)
        if kwargs.get('async_req'):
            return self.get_user_with_http_info(user_gid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_user_with_http_info(user_gid, **kwargs)  # noqa: E501
            return data

    def get_user_with_http_info(self, user_gid, **kwargs):  # noqa: E501
        """Get a user  # noqa: E501

        Returns the full user record for the single user with the provided ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_with_http_info(user_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_gid: A string identifying a user. This can either be the string \"me\", an email, or the gid of a user. (required)
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: UserResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_gid', 'opt_fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('header_params')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_gid' is set
        if ('user_gid' not in params or
                params['user_gid'] is None):
            raise ValueError("Missing the required parameter `user_gid` when calling `get_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_gid' in params:
            path_params['user_gid'] = params['user_gid']  # noqa: E501

        query_params = []
        if 'opt_fields' in params:
            query_params.append(('opt_fields', params['opt_fields']))  # noqa: E501
            collection_formats['opt_fields'] = 'csv'  # noqa: E501

        header_params = kwargs.get("header_params", {})

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/users/{user_gid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserResponseData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_users(self, **kwargs):  # noqa: E501
        """Get multiple users  # noqa: E501

        Returns the user records for all users in all workspaces and organizations accessible to the authenticated user. Accepts an optional workspace ID parameter. Results are sorted by user ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace: The workspace or organization ID to filter users on.
        :param str team: The team ID to filter users on.
        :param int limit: Results per page. The number of objects to return per page. The value must be between 1 and 100.
        :param str offset: Offset token. An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results. 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: UserResponseArray
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = kwargs.get("_return_http_data_only", True)
        if kwargs.get('async_req'):
            return self.get_users_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_users_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_users_with_http_info(self, **kwargs):  # noqa: E501
        """Get multiple users  # noqa: E501

        Returns the user records for all users in all workspaces and organizations accessible to the authenticated user. Accepts an optional workspace ID parameter. Results are sorted by user ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace: The workspace or organization ID to filter users on.
        :param str team: The team ID to filter users on.
        :param int limit: Results per page. The number of objects to return per page. The value must be between 1 and 100.
        :param str offset: Offset token. An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results. 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: UserResponseArray
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['workspace', 'team', 'limit', 'offset', 'opt_fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('header_params')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_users" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'workspace' in params:
            query_params.append(('workspace', params['workspace']))  # noqa: E501
        if 'team' in params:
            query_params.append(('team', params['team']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'opt_fields' in params:
            query_params.append(('opt_fields', params['opt_fields']))  # noqa: E501
            collection_formats['opt_fields'] = 'csv'  # noqa: E501

        header_params = kwargs.get("header_params", {})

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/users', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserResponseArray',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_users_for_team(self, team_gid, **kwargs):  # noqa: E501
        """Get users in a team  # noqa: E501

        Returns the compact records for all users that are members of the team. Results are sorted alphabetically and limited to 2000. For more results use the `/users` endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users_for_team(team_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str team_gid: Globally unique identifier for the team. (required)
        :param str offset: Offset token. An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results. 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: UserResponseArray
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = kwargs.get("_return_http_data_only", True)
        if kwargs.get('async_req'):
            return self.get_users_for_team_with_http_info(team_gid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_users_for_team_with_http_info(team_gid, **kwargs)  # noqa: E501
            return data

    def get_users_for_team_with_http_info(self, team_gid, **kwargs):  # noqa: E501
        """Get users in a team  # noqa: E501

        Returns the compact records for all users that are members of the team. Results are sorted alphabetically and limited to 2000. For more results use the `/users` endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users_for_team_with_http_info(team_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str team_gid: Globally unique identifier for the team. (required)
        :param str offset: Offset token. An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results. 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: UserResponseArray
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['team_gid', 'offset', 'opt_fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('header_params')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_users_for_team" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'team_gid' is set
        if ('team_gid' not in params or
                params['team_gid'] is None):
            raise ValueError("Missing the required parameter `team_gid` when calling `get_users_for_team`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'team_gid' in params:
            path_params['team_gid'] = params['team_gid']  # noqa: E501

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'opt_fields' in params:
            query_params.append(('opt_fields', params['opt_fields']))  # noqa: E501
            collection_formats['opt_fields'] = 'csv'  # noqa: E501

        header_params = kwargs.get("header_params", {})

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/teams/{team_gid}/users', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserResponseArray',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_users_for_workspace(self, workspace_gid, **kwargs):  # noqa: E501
        """Get users in a workspace or organization  # noqa: E501

        Returns the compact records for all users in the specified workspace or organization. Results are sorted alphabetically and limited to 2000. For more results use the `/users` endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users_for_workspace(workspace_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace_gid: Globally unique identifier for the workspace or organization. (required)
        :param str offset: Offset token. An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results. 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: UserResponseArray
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = kwargs.get("_return_http_data_only", True)
        if kwargs.get('async_req'):
            return self.get_users_for_workspace_with_http_info(workspace_gid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_users_for_workspace_with_http_info(workspace_gid, **kwargs)  # noqa: E501
            return data

    def get_users_for_workspace_with_http_info(self, workspace_gid, **kwargs):  # noqa: E501
        """Get users in a workspace or organization  # noqa: E501

        Returns the compact records for all users in the specified workspace or organization. Results are sorted alphabetically and limited to 2000. For more results use the `/users` endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users_for_workspace_with_http_info(workspace_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workspace_gid: Globally unique identifier for the workspace or organization. (required)
        :param str offset: Offset token. An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results. 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: UserResponseArray
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['workspace_gid', 'offset', 'opt_fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('header_params')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_users_for_workspace" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'workspace_gid' is set
        if ('workspace_gid' not in params or
                params['workspace_gid'] is None):
            raise ValueError("Missing the required parameter `workspace_gid` when calling `get_users_for_workspace`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workspace_gid' in params:
            path_params['workspace_gid'] = params['workspace_gid']  # noqa: E501

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'opt_fields' in params:
            query_params.append(('opt_fields', params['opt_fields']))  # noqa: E501
            collection_formats['opt_fields'] = 'csv'  # noqa: E501

        header_params = kwargs.get("header_params", {})

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/workspaces/{workspace_gid}/users', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserResponseArray',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AttachmentRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'resource_subtype': 'str',
        'file': 'str',
        'parent': 'str',
        'url': 'str',
        'name': 'str',
        'connect_to_app': 'bool'
    }

    attribute_map = {
        'resource_subtype': 'resource_subtype',
        'file': 'file',
        'parent': 'parent',
        'url': 'url',
        'name': 'name',
        'connect_to_app': 'connect_to_app'
    }

    def __init__(self, resource_subtype=None, file=None, parent=None, url=None, name=None, connect_to_app=None):  # noqa: E501
        """AttachmentRequest - a model defined in Swagger"""  # noqa: E501
        self._resource_subtype = None
        self._file = None
        self._parent = None
        self._url = None
        self._name = None
        self._connect_to_app = None
        self.discriminator = None
        if resource_subtype is not None:
            self.resource_subtype = resource_subtype
        if file is not None:
            self.file = file
        self.parent = parent
        if url is not None:
            self.url = url
        if name is not None:
            self.name = name
        if connect_to_app is not None:
            self.connect_to_app = connect_to_app

    @property
    def resource_subtype(self):
        """Gets the resource_subtype of this AttachmentRequest.  # noqa: E501

        The type of the attachment. Must be one of the given values. If not specified, a file attachment of type `asana` will be assumed. Note that if the value of `resource_subtype` is `external`, a `parent`, `name`, and `url` must also be provided.   # noqa: E501

        :return: The resource_subtype of this AttachmentRequest.  # noqa: E501
        :rtype: str
        """
        return self._resource_subtype

    @resource_subtype.setter
    def resource_subtype(self, resource_subtype):
        """Sets the resource_subtype of this AttachmentRequest.

        The type of the attachment. Must be one of the given values. If not specified, a file attachment of type `asana` will be assumed. Note that if the value of `resource_subtype` is `external`, a `parent`, `name`, and `url` must also be provided.   # noqa: E501

        :param resource_subtype: The resource_subtype of this AttachmentRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["asana", "dropbox", "gdrive", "onedrive", "box", "vimeo", "external"]  # noqa: E501
        if resource_subtype not in allowed_values:
            raise ValueError(
                "Invalid value for `resource_subtype` ({0}), must be one of {1}"  # noqa: E501
                .format(resource_subtype, allowed_values)
            )

        self._resource_subtype = resource_subtype

    @property
    def file(self):
        """Gets the file of this AttachmentRequest.  # noqa: E501

        Required for `asana` attachments.   # noqa: E501

        :return: The file of this AttachmentRequest.  # noqa: E501
        :rtype: str
        """
        return self._file

    @file.setter
    def file(self, file):
        """Sets the file of this AttachmentRequest.

        Required for `asana` attachments.   # noqa: E501

        :param file: The file of this AttachmentRequest.  # noqa: E501
        :type: str
        """

        self._file = file

    @property
    def parent(self):
        """Gets the parent of this AttachmentRequest.  # noqa: E501

        Required identifier of the parent task, project, or project_brief, as a string.   # noqa: E501

        :return: The parent of this AttachmentRequest.  # noqa: E501
        :rtype: str
        """
        return self._parent

    @parent.setter
    def parent(self, parent):
        """Sets the parent of this AttachmentRequest.

        Required identifier of the parent task, project, or project_brief, as a string.   # noqa: E501

        :param parent: The parent of this AttachmentRequest.  # noqa: E501
        :type: str
        """
        if parent is None:
            raise ValueError("Invalid value for `parent`, must not be `None`")  # noqa: E501

        self._parent = parent

    @property
    def url(self):
        """Gets the url of this AttachmentRequest.  # noqa: E501

        The URL of the external resource being attached. Required for attachments of type `external`.   # noqa: E501

        :return: The url of this AttachmentRequest.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this AttachmentRequest.

        The URL of the external resource being attached. Required for attachments of type `external`.   # noqa: E501

        :param url: The url of this AttachmentRequest.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def name(self):
        """Gets the name of this AttachmentRequest.  # noqa: E501

        The name of the external resource being attached. Required for attachments of type `external`.   # noqa: E501

        :return: The name of this AttachmentRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AttachmentRequest.

        The name of the external resource being attached. Required for attachments of type `external`.   # noqa: E501

        :param name: The name of this AttachmentRequest.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def connect_to_app(self):
        """Gets the connect_to_app of this AttachmentRequest.  # noqa: E501

        *Optional*. Only relevant for external attachments with a parent task. A boolean indicating whether the current app should be connected with the attachment for the purposes of showing an app components widget. Requires the app to have been added to a project the parent task is in.   # noqa: E501

        :return: The connect_to_app of this AttachmentRequest.  # noqa: E501
        :rtype: bool
        """
        return self._connect_to_app

    @connect_to_app.setter
    def connect_to_app(self, connect_to_app):
        """Sets the connect_to_app of this AttachmentRequest.

        *Optional*. Only relevant for external attachments with a parent task. A boolean indicating whether the current app should be connected with the attachment for the purposes of showing an app components widget. Requires the app to have been added to a project the parent task is in.   # noqa: E501

        :param connect_to_app: The connect_to_app of this AttachmentRequest.  # noqa: E501
        :type: bool
        """

        self._connect_to_app = connect_to_app

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AttachmentRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AttachmentRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class StoryResponseOldDates(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'start_on': 'date',
        'due_at': 'datetime',
        'due_on': 'date'
    }

    attribute_map = {
        'start_on': 'start_on',
        'due_at': 'due_at',
        'due_on': 'due_on'
    }

    def __init__(self, start_on=None, due_at=None, due_on=None):  # noqa: E501
        """StoryResponseOldDates - a model defined in Swagger"""  # noqa: E501
        self._start_on = None
        self._due_at = None
        self._due_on = None
        self.discriminator = None
        if start_on is not None:
            self.start_on = start_on
        if due_at is not None:
            self.due_at = due_at
        if due_on is not None:
            self.due_on = due_on

    @property
    def start_on(self):
        """Gets the start_on of this StoryResponseOldDates.  # noqa: E501

        The day on which work for this goal begins, or null if the goal has no start date. This takes a date with `YYYY-MM-DD` format, and cannot be set unless there is an accompanying due date.  # noqa: E501

        :return: The start_on of this StoryResponseOldDates.  # noqa: E501
        :rtype: date
        """
        return self._start_on

    @start_on.setter
    def start_on(self, start_on):
        """Sets the start_on of this StoryResponseOldDates.

        The day on which work for this goal begins, or null if the goal has no start date. This takes a date with `YYYY-MM-DD` format, and cannot be set unless there is an accompanying due date.  # noqa: E501

        :param start_on: The start_on of this StoryResponseOldDates.  # noqa: E501
        :type: date
        """

        self._start_on = start_on

    @property
    def due_at(self):
        """Gets the due_at of this StoryResponseOldDates.  # noqa: E501

        The UTC date and time on which this task is due, or null if the task has no due time. This takes an ISO 8601 date string in UTC and should not be used together with `due_on`.  # noqa: E501

        :return: The due_at of this StoryResponseOldDates.  # noqa: E501
        :rtype: datetime
        """
        return self._due_at

    @due_at.setter
    def due_at(self, due_at):
        """Sets the due_at of this StoryResponseOldDates.

        The UTC date and time on which this task is due, or null if the task has no due time. This takes an ISO 8601 date string in UTC and should not be used together with `due_on`.  # noqa: E501

        :param due_at: The due_at of this StoryResponseOldDates.  # noqa: E501
        :type: datetime
        """

        self._due_at = due_at

    @property
    def due_on(self):
        """Gets the due_on of this StoryResponseOldDates.  # noqa: E501

        The localized day on which this goal is due. This takes a date with format `YYYY-MM-DD`.  # noqa: E501

        :return: The due_on of this StoryResponseOldDates.  # noqa: E501
        :rtype: date
        """
        return self._due_on

    @due_on.setter
    def due_on(self, due_on):
        """Sets the due_on of this StoryResponseOldDates.

        The localized day on which this goal is due. This takes a date with format `YYYY-MM-DD`.  # noqa: E501

        :param due_on: The due_on of this StoryResponseOldDates.  # noqa: E501
        :type: date
        """

        self._due_on = due_on

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StoryResponseOldDates, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StoryResponseOldDates):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TaskSetParentRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'parent': 'str',
        'insert_after': 'str',
        'insert_before': 'str'
    }

    attribute_map = {
        'parent': 'parent',
        'insert_after': 'insert_after',
        'insert_before': 'insert_before'
    }

    def __init__(self, parent=None, insert_after=None, insert_before=None):  # noqa: E501
        """TaskSetParentRequest - a model defined in Swagger"""  # noqa: E501
        self._parent = None
        self._insert_after = None
        self._insert_before = None
        self.discriminator = None
        self.parent = parent
        if insert_after is not None:
            self.insert_after = insert_after
        if insert_before is not None:
            self.insert_before = insert_before

    @property
    def parent(self):
        """Gets the parent of this TaskSetParentRequest.  # noqa: E501

        The new parent of the task, or `null` for no parent.  # noqa: E501

        :return: The parent of this TaskSetParentRequest.  # noqa: E501
        :rtype: str
        """
        return self._parent

    @parent.setter
    def parent(self, parent):
        """Sets the parent of this TaskSetParentRequest.

        The new parent of the task, or `null` for no parent.  # noqa: E501

        :param parent: The parent of this TaskSetParentRequest.  # noqa: E501
        :type: str
        """
        if parent is None:
            raise ValueError("Invalid value for `parent`, must not be `None`")  # noqa: E501

        self._parent = parent

    @property
    def insert_after(self):
        """Gets the insert_after of this TaskSetParentRequest.  # noqa: E501

        A subtask of the parent to insert the task after, or `null` to insert at the beginning of the list.  # noqa: E501

        :return: The insert_after of this TaskSetParentRequest.  # noqa: E501
        :rtype: str
        """
        return self._insert_after

    @insert_after.setter
    def insert_after(self, insert_after):
        """Sets the insert_after of this TaskSetParentRequest.

        A subtask of the parent to insert the task after, or `null` to insert at the beginning of the list.  # noqa: E501

        :param insert_after: The insert_after of this TaskSetParentRequest.  # noqa: E501
        :type: str
        """

        self._insert_after = insert_after

    @property
    def insert_before(self):
        """Gets the insert_before of this TaskSetParentRequest.  # noqa: E501

        A subtask of the parent to insert the task before, or `null` to insert at the end of the list.  # noqa: E501

        :return: The insert_before of this TaskSetParentRequest.  # noqa: E501
        :rtype: str
        """
        return self._insert_before

    @insert_before.setter
    def insert_before(self, insert_before):
        """Sets the insert_before of this TaskSetParentRequest.

        A subtask of the parent to insert the task before, or `null` to insert at the end of the list.  # noqa: E501

        :param insert_before: The insert_before of this TaskSetParentRequest.  # noqa: E501
        :type: str
        """

        self._insert_before = insert_before

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TaskSetParentRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TaskSetParentRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TaskRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'gid': 'str',
        'resource_type': 'str',
        'name': 'str',
        'resource_subtype': 'str',
        'created_by': 'AttachmentResponseParentCreatedBy',
        'approval_status': 'str',
        'assignee_status': 'str',
        'completed': 'bool',
        'completed_at': 'datetime',
        'completed_by': 'TaskBaseCompletedBy',
        'created_at': 'datetime',
        'dependencies': 'list[TaskBaseDependencies]',
        'dependents': 'list[TaskBaseDependencies]',
        'due_at': 'datetime',
        'due_on': 'date',
        'external': 'TaskBaseExternal',
        'html_notes': 'str',
        'hearted': 'bool',
        'hearts': 'list[GoalResponseLikes]',
        'is_rendered_as_separator': 'bool',
        'liked': 'bool',
        'likes': 'list[GoalResponseLikes]',
        'memberships': 'list[TaskBaseMemberships]',
        'modified_at': 'datetime',
        'notes': 'str',
        'num_hearts': 'int',
        'num_likes': 'int',
        'num_subtasks': 'int',
        'start_at': 'datetime',
        'start_on': 'date',
        'actual_time_minutes': 'float',
        'assignee': 'str',
        'assignee_section': 'str',
        'custom_fields': 'dict(str, str)',
        'followers': 'list[str]',
        'parent': 'str',
        'projects': 'list[str]',
        'tags': 'list[str]',
        'workspace': 'str'
    }

    attribute_map = {
        'gid': 'gid',
        'resource_type': 'resource_type',
        'name': 'name',
        'resource_subtype': 'resource_subtype',
        'created_by': 'created_by',
        'approval_status': 'approval_status',
        'assignee_status': 'assignee_status',
        'completed': 'completed',
        'completed_at': 'completed_at',
        'completed_by': 'completed_by',
        'created_at': 'created_at',
        'dependencies': 'dependencies',
        'dependents': 'dependents',
        'due_at': 'due_at',
        'due_on': 'due_on',
        'external': 'external',
        'html_notes': 'html_notes',
        'hearted': 'hearted',
        'hearts': 'hearts',
        'is_rendered_as_separator': 'is_rendered_as_separator',
        'liked': 'liked',
        'likes': 'likes',
        'memberships': 'memberships',
        'modified_at': 'modified_at',
        'notes': 'notes',
        'num_hearts': 'num_hearts',
        'num_likes': 'num_likes',
        'num_subtasks': 'num_subtasks',
        'start_at': 'start_at',
        'start_on': 'start_on',
        'actual_time_minutes': 'actual_time_minutes',
        'assignee': 'assignee',
        'assignee_section': 'assignee_section',
        'custom_fields': 'custom_fields',
        'followers': 'followers',
        'parent': 'parent',
        'projects': 'projects',
        'tags': 'tags',
        'workspace': 'workspace'
    }

    def __init__(self, gid=None, resource_type=None, name=None, resource_subtype=None, created_by=None, approval_status=None, assignee_status=None, completed=None, completed_at=None, completed_by=None, created_at=None, dependencies=None, dependents=None, due_at=None, due_on=None, external=None, html_notes=None, hearted=None, hearts=None, is_rendered_as_separator=None, liked=None, likes=None, memberships=None, modified_at=None, notes=None, num_hearts=None, num_likes=None, num_subtasks=None, start_at=None, start_on=None, actual_time_minutes=None, assignee=None, assignee_section=None, custom_fields=None, followers=None, parent=None, projects=None, tags=None, workspace=None):  # noqa: E501
        """TaskRequest - a model defined in Swagger"""  # noqa: E501
        self._gid = None
        self._resource_type = None
        self._name = None
        self._resource_subtype = None
        self._created_by = None
        self._approval_status = None
        self._assignee_status = None
        self._completed = None
        self._completed_at = None
        self._completed_by = None
        self._created_at = None
        self._dependencies = None
        self._dependents = None
        self._due_at = None
        self._due_on = None
        self._external = None
        self._html_notes = None
        self._hearted = None
        self._hearts = None
        self._is_rendered_as_separator = None
        self._liked = None
        self._likes = None
        self._memberships = None
        self._modified_at = None
        self._notes = None
        self._num_hearts = None
        self._num_likes = None
        self._num_subtasks = None
        self._start_at = None
        self._start_on = None
        self._actual_time_minutes = None
        self._assignee = None
        self._assignee_section = None
        self._custom_fields = None
        self._followers = None
        self._parent = None
        self._projects = None
        self._tags = None
        self._workspace = None
        self.discriminator = None
        if gid is not None:
            self.gid = gid
        if resource_type is not None:
            self.resource_type = resource_type
        if name is not None:
            self.name = name
        if resource_subtype is not None:
            self.resource_subtype = resource_subtype
        if created_by is not None:
            self.created_by = created_by
        if approval_status is not None:
            self.approval_status = approval_status
        if assignee_status is not None:
            self.assignee_status = assignee_status
        if completed is not None:
            self.completed = completed
        if completed_at is not None:
            self.completed_at = completed_at
        if completed_by is not None:
            self.completed_by = completed_by
        if created_at is not None:
            self.created_at = created_at
        if dependencies is not None:
            self.dependencies = dependencies
        if dependents is not None:
            self.dependents = dependents
        if due_at is not None:
            self.due_at = due_at
        if due_on is not None:
            self.due_on = due_on
        if external is not None:
            self.external = external
        if html_notes is not None:
            self.html_notes = html_notes
        if hearted is not None:
            self.hearted = hearted
        if hearts is not None:
            self.hearts = hearts
        if is_rendered_as_separator is not None:
            self.is_rendered_as_separator = is_rendered_as_separator
        if liked is not None:
            self.liked = liked
        if likes is not None:
            self.likes = likes
        if memberships is not None:
            self.memberships = memberships
        if modified_at is not None:
            self.modified_at = modified_at
        if notes is not None:
            self.notes = notes
        if num_hearts is not None:
            self.num_hearts = num_hearts
        if num_likes is not None:
            self.num_likes = num_likes
        if num_subtasks is not None:
            self.num_subtasks = num_subtasks
        if start_at is not None:
            self.start_at = start_at
        if start_on is not None:
            self.start_on = start_on
        if actual_time_minutes is not None:
            self.actual_time_minutes = actual_time_minutes
        if assignee is not None:
            self.assignee = assignee
        if assignee_section is not None:
            self.assignee_section = assignee_section
        if custom_fields is not None:
            self.custom_fields = custom_fields
        if followers is not None:
            self.followers = followers
        if parent is not None:
            self.parent = parent
        if projects is not None:
            self.projects = projects
        if tags is not None:
            self.tags = tags
        if workspace is not None:
            self.workspace = workspace

    @property
    def gid(self):
        """Gets the gid of this TaskRequest.  # noqa: E501

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :return: The gid of this TaskRequest.  # noqa: E501
        :rtype: str
        """
        return self._gid

    @gid.setter
    def gid(self, gid):
        """Sets the gid of this TaskRequest.

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :param gid: The gid of this TaskRequest.  # noqa: E501
        :type: str
        """

        self._gid = gid

    @property
    def resource_type(self):
        """Gets the resource_type of this TaskRequest.  # noqa: E501

        The base type of this resource.  # noqa: E501

        :return: The resource_type of this TaskRequest.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this TaskRequest.

        The base type of this resource.  # noqa: E501

        :param resource_type: The resource_type of this TaskRequest.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def name(self):
        """Gets the name of this TaskRequest.  # noqa: E501

        Name of the task. This is generally a short sentence fragment that fits on a line in the UI for maximum readability. However, it can be longer.  # noqa: E501

        :return: The name of this TaskRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TaskRequest.

        Name of the task. This is generally a short sentence fragment that fits on a line in the UI for maximum readability. However, it can be longer.  # noqa: E501

        :param name: The name of this TaskRequest.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def resource_subtype(self):
        """Gets the resource_subtype of this TaskRequest.  # noqa: E501

        The subtype of this resource. Different subtypes retain many of the same fields and behavior, but may render differently in Asana or represent resources with different semantic meaning. The resource_subtype `milestone` represent a single moment in time. This means tasks with this subtype cannot have a start_date.  # noqa: E501

        :return: The resource_subtype of this TaskRequest.  # noqa: E501
        :rtype: str
        """
        return self._resource_subtype

    @resource_subtype.setter
    def resource_subtype(self, resource_subtype):
        """Sets the resource_subtype of this TaskRequest.

        The subtype of this resource. Different subtypes retain many of the same fields and behavior, but may render differently in Asana or represent resources with different semantic meaning. The resource_subtype `milestone` represent a single moment in time. This means tasks with this subtype cannot have a start_date.  # noqa: E501

        :param resource_subtype: The resource_subtype of this TaskRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["default_task", "milestone", "section", "approval"]  # noqa: E501
        if resource_subtype not in allowed_values:
            raise ValueError(
                "Invalid value for `resource_subtype` ({0}), must be one of {1}"  # noqa: E501
                .format(resource_subtype, allowed_values)
            )

        self._resource_subtype = resource_subtype

    @property
    def created_by(self):
        """Gets the created_by of this TaskRequest.  # noqa: E501


        :return: The created_by of this TaskRequest.  # noqa: E501
        :rtype: AttachmentResponseParentCreatedBy
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this TaskRequest.


        :param created_by: The created_by of this TaskRequest.  # noqa: E501
        :type: AttachmentResponseParentCreatedBy
        """

        self._created_by = created_by

    @property
    def approval_status(self):
        """Gets the approval_status of this TaskRequest.  # noqa: E501

        *Conditional* Reflects the approval status of this task. This field is kept in sync with `completed`, meaning `pending` translates to false while `approved`, `rejected`, and `changes_requested` translate to true. If you set completed to true, this field will be set to `approved`.  # noqa: E501

        :return: The approval_status of this TaskRequest.  # noqa: E501
        :rtype: str
        """
        return self._approval_status

    @approval_status.setter
    def approval_status(self, approval_status):
        """Sets the approval_status of this TaskRequest.

        *Conditional* Reflects the approval status of this task. This field is kept in sync with `completed`, meaning `pending` translates to false while `approved`, `rejected`, and `changes_requested` translate to true. If you set completed to true, this field will be set to `approved`.  # noqa: E501

        :param approval_status: The approval_status of this TaskRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["pending", "approved", "rejected", "changes_requested"]  # noqa: E501
        if approval_status not in allowed_values:
            raise ValueError(
                "Invalid value for `approval_status` ({0}), must be one of {1}"  # noqa: E501
                .format(approval_status, allowed_values)
            )

        self._approval_status = approval_status

    @property
    def assignee_status(self):
        """Gets the assignee_status of this TaskRequest.  # noqa: E501

        *Deprecated* Scheduling status of this task for the user it is assigned to. This field can only be set if the assignee is non-null. Setting this field to \"inbox\" or \"upcoming\" inserts it at the top of the section, while the other options will insert at the bottom.  # noqa: E501

        :return: The assignee_status of this TaskRequest.  # noqa: E501
        :rtype: str
        """
        return self._assignee_status

    @assignee_status.setter
    def assignee_status(self, assignee_status):
        """Sets the assignee_status of this TaskRequest.

        *Deprecated* Scheduling status of this task for the user it is assigned to. This field can only be set if the assignee is non-null. Setting this field to \"inbox\" or \"upcoming\" inserts it at the top of the section, while the other options will insert at the bottom.  # noqa: E501

        :param assignee_status: The assignee_status of this TaskRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["today", "upcoming", "later", "new", "inbox"]  # noqa: E501
        if assignee_status not in allowed_values:
            raise ValueError(
                "Invalid value for `assignee_status` ({0}), must be one of {1}"  # noqa: E501
                .format(assignee_status, allowed_values)
            )

        self._assignee_status = assignee_status

    @property
    def completed(self):
        """Gets the completed of this TaskRequest.  # noqa: E501

        True if the task is currently marked complete, false if not.  # noqa: E501

        :return: The completed of this TaskRequest.  # noqa: E501
        :rtype: bool
        """
        return self._completed

    @completed.setter
    def completed(self, completed):
        """Sets the completed of this TaskRequest.

        True if the task is currently marked complete, false if not.  # noqa: E501

        :param completed: The completed of this TaskRequest.  # noqa: E501
        :type: bool
        """

        self._completed = completed

    @property
    def completed_at(self):
        """Gets the completed_at of this TaskRequest.  # noqa: E501

        The time at which this task was completed, or null if the task is incomplete.  # noqa: E501

        :return: The completed_at of this TaskRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._completed_at

    @completed_at.setter
    def completed_at(self, completed_at):
        """Sets the completed_at of this TaskRequest.

        The time at which this task was completed, or null if the task is incomplete.  # noqa: E501

        :param completed_at: The completed_at of this TaskRequest.  # noqa: E501
        :type: datetime
        """

        self._completed_at = completed_at

    @property
    def completed_by(self):
        """Gets the completed_by of this TaskRequest.  # noqa: E501


        :return: The completed_by of this TaskRequest.  # noqa: E501
        :rtype: TaskBaseCompletedBy
        """
        return self._completed_by

    @completed_by.setter
    def completed_by(self, completed_by):
        """Sets the completed_by of this TaskRequest.


        :param completed_by: The completed_by of this TaskRequest.  # noqa: E501
        :type: TaskBaseCompletedBy
        """

        self._completed_by = completed_by

    @property
    def created_at(self):
        """Gets the created_at of this TaskRequest.  # noqa: E501

        The time at which this resource was created.  # noqa: E501

        :return: The created_at of this TaskRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this TaskRequest.

        The time at which this resource was created.  # noqa: E501

        :param created_at: The created_at of this TaskRequest.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def dependencies(self):
        """Gets the dependencies of this TaskRequest.  # noqa: E501

        [Opt In](/docs/inputoutput-options). Array of resources referencing tasks that this task depends on. The objects contain only the gid of the dependency.  # noqa: E501

        :return: The dependencies of this TaskRequest.  # noqa: E501
        :rtype: list[TaskBaseDependencies]
        """
        return self._dependencies

    @dependencies.setter
    def dependencies(self, dependencies):
        """Sets the dependencies of this TaskRequest.

        [Opt In](/docs/inputoutput-options). Array of resources referencing tasks that this task depends on. The objects contain only the gid of the dependency.  # noqa: E501

        :param dependencies: The dependencies of this TaskRequest.  # noqa: E501
        :type: list[TaskBaseDependencies]
        """

        self._dependencies = dependencies

    @property
    def dependents(self):
        """Gets the dependents of this TaskRequest.  # noqa: E501

        [Opt In](/docs/inputoutput-options). Array of resources referencing tasks that depend on this task. The objects contain only the ID of the dependent.  # noqa: E501

        :return: The dependents of this TaskRequest.  # noqa: E501
        :rtype: list[TaskBaseDependencies]
        """
        return self._dependents

    @dependents.setter
    def dependents(self, dependents):
        """Sets the dependents of this TaskRequest.

        [Opt In](/docs/inputoutput-options). Array of resources referencing tasks that depend on this task. The objects contain only the ID of the dependent.  # noqa: E501

        :param dependents: The dependents of this TaskRequest.  # noqa: E501
        :type: list[TaskBaseDependencies]
        """

        self._dependents = dependents

    @property
    def due_at(self):
        """Gets the due_at of this TaskRequest.  # noqa: E501

        The UTC date and time on which this task is due, or null if the task has no due time. This takes an ISO 8601 date string in UTC and should not be used together with `due_on`.  # noqa: E501

        :return: The due_at of this TaskRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._due_at

    @due_at.setter
    def due_at(self, due_at):
        """Sets the due_at of this TaskRequest.

        The UTC date and time on which this task is due, or null if the task has no due time. This takes an ISO 8601 date string in UTC and should not be used together with `due_on`.  # noqa: E501

        :param due_at: The due_at of this TaskRequest.  # noqa: E501
        :type: datetime
        """

        self._due_at = due_at

    @property
    def due_on(self):
        """Gets the due_on of this TaskRequest.  # noqa: E501

        The localized date on which this task is due, or null if the task has no due date. This takes a date with `YYYY-MM-DD` format and should not be used together with `due_at`.  # noqa: E501

        :return: The due_on of this TaskRequest.  # noqa: E501
        :rtype: date
        """
        return self._due_on

    @due_on.setter
    def due_on(self, due_on):
        """Sets the due_on of this TaskRequest.

        The localized date on which this task is due, or null if the task has no due date. This takes a date with `YYYY-MM-DD` format and should not be used together with `due_at`.  # noqa: E501

        :param due_on: The due_on of this TaskRequest.  # noqa: E501
        :type: date
        """

        self._due_on = due_on

    @property
    def external(self):
        """Gets the external of this TaskRequest.  # noqa: E501


        :return: The external of this TaskRequest.  # noqa: E501
        :rtype: TaskBaseExternal
        """
        return self._external

    @external.setter
    def external(self, external):
        """Sets the external of this TaskRequest.


        :param external: The external of this TaskRequest.  # noqa: E501
        :type: TaskBaseExternal
        """

        self._external = external

    @property
    def html_notes(self):
        """Gets the html_notes of this TaskRequest.  # noqa: E501

        [Opt In](/docs/inputoutput-options). The notes of the text with formatting as HTML.  # noqa: E501

        :return: The html_notes of this TaskRequest.  # noqa: E501
        :rtype: str
        """
        return self._html_notes

    @html_notes.setter
    def html_notes(self, html_notes):
        """Sets the html_notes of this TaskRequest.

        [Opt In](/docs/inputoutput-options). The notes of the text with formatting as HTML.  # noqa: E501

        :param html_notes: The html_notes of this TaskRequest.  # noqa: E501
        :type: str
        """

        self._html_notes = html_notes

    @property
    def hearted(self):
        """Gets the hearted of this TaskRequest.  # noqa: E501

        *Deprecated - please use liked instead* True if the task is hearted by the authorized user, false if not.  # noqa: E501

        :return: The hearted of this TaskRequest.  # noqa: E501
        :rtype: bool
        """
        return self._hearted

    @hearted.setter
    def hearted(self, hearted):
        """Sets the hearted of this TaskRequest.

        *Deprecated - please use liked instead* True if the task is hearted by the authorized user, false if not.  # noqa: E501

        :param hearted: The hearted of this TaskRequest.  # noqa: E501
        :type: bool
        """

        self._hearted = hearted

    @property
    def hearts(self):
        """Gets the hearts of this TaskRequest.  # noqa: E501

        *Deprecated - please use likes instead* Array of likes for users who have hearted this task.  # noqa: E501

        :return: The hearts of this TaskRequest.  # noqa: E501
        :rtype: list[GoalResponseLikes]
        """
        return self._hearts

    @hearts.setter
    def hearts(self, hearts):
        """Sets the hearts of this TaskRequest.

        *Deprecated - please use likes instead* Array of likes for users who have hearted this task.  # noqa: E501

        :param hearts: The hearts of this TaskRequest.  # noqa: E501
        :type: list[GoalResponseLikes]
        """

        self._hearts = hearts

    @property
    def is_rendered_as_separator(self):
        """Gets the is_rendered_as_separator of this TaskRequest.  # noqa: E501

        [Opt In](/docs/inputoutput-options). In some contexts tasks can be rendered as a visual separator; for instance, subtasks can appear similar to [sections](/reference/sections) without being true `section` objects. If a `task` object is rendered this way in any context it will have the property `is_rendered_as_separator` set to `true`.  # noqa: E501

        :return: The is_rendered_as_separator of this TaskRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_rendered_as_separator

    @is_rendered_as_separator.setter
    def is_rendered_as_separator(self, is_rendered_as_separator):
        """Sets the is_rendered_as_separator of this TaskRequest.

        [Opt In](/docs/inputoutput-options). In some contexts tasks can be rendered as a visual separator; for instance, subtasks can appear similar to [sections](/reference/sections) without being true `section` objects. If a `task` object is rendered this way in any context it will have the property `is_rendered_as_separator` set to `true`.  # noqa: E501

        :param is_rendered_as_separator: The is_rendered_as_separator of this TaskRequest.  # noqa: E501
        :type: bool
        """

        self._is_rendered_as_separator = is_rendered_as_separator

    @property
    def liked(self):
        """Gets the liked of this TaskRequest.  # noqa: E501

        True if the task is liked by the authorized user, false if not.  # noqa: E501

        :return: The liked of this TaskRequest.  # noqa: E501
        :rtype: bool
        """
        return self._liked

    @liked.setter
    def liked(self, liked):
        """Sets the liked of this TaskRequest.

        True if the task is liked by the authorized user, false if not.  # noqa: E501

        :param liked: The liked of this TaskRequest.  # noqa: E501
        :type: bool
        """

        self._liked = liked

    @property
    def likes(self):
        """Gets the likes of this TaskRequest.  # noqa: E501

        Array of likes for users who have liked this task.  # noqa: E501

        :return: The likes of this TaskRequest.  # noqa: E501
        :rtype: list[GoalResponseLikes]
        """
        return self._likes

    @likes.setter
    def likes(self, likes):
        """Sets the likes of this TaskRequest.

        Array of likes for users who have liked this task.  # noqa: E501

        :param likes: The likes of this TaskRequest.  # noqa: E501
        :type: list[GoalResponseLikes]
        """

        self._likes = likes

    @property
    def memberships(self):
        """Gets the memberships of this TaskRequest.  # noqa: E501

        *Create-only*. Array of projects this task is associated with and the section it is in. At task creation time, this array can be used to add the task to specific sections. After task creation, these associations can be modified using the `addProject` and `removeProject` endpoints. Note that over time, more types of memberships may be added to this property.  # noqa: E501

        :return: The memberships of this TaskRequest.  # noqa: E501
        :rtype: list[TaskBaseMemberships]
        """
        return self._memberships

    @memberships.setter
    def memberships(self, memberships):
        """Sets the memberships of this TaskRequest.

        *Create-only*. Array of projects this task is associated with and the section it is in. At task creation time, this array can be used to add the task to specific sections. After task creation, these associations can be modified using the `addProject` and `removeProject` endpoints. Note that over time, more types of memberships may be added to this property.  # noqa: E501

        :param memberships: The memberships of this TaskRequest.  # noqa: E501
        :type: list[TaskBaseMemberships]
        """

        self._memberships = memberships

    @property
    def modified_at(self):
        """Gets the modified_at of this TaskRequest.  # noqa: E501

        The time at which this task was last modified.  The following conditions will change `modified_at`:  - story is created on a task - story is trashed on a task - attachment is trashed on a task - task is assigned or unassigned - custom field value is changed - the task itself is trashed - Or if any of the following fields are updated:   - completed   - name   - due_date   - description   - attachments   - items   - schedule_status  The following conditions will _not_ change `modified_at`:  - moving to a new container (project, portfolio, etc) - comments being added to the task (but the stories they generate   _will_ affect `modified_at`)  # noqa: E501

        :return: The modified_at of this TaskRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this TaskRequest.

        The time at which this task was last modified.  The following conditions will change `modified_at`:  - story is created on a task - story is trashed on a task - attachment is trashed on a task - task is assigned or unassigned - custom field value is changed - the task itself is trashed - Or if any of the following fields are updated:   - completed   - name   - due_date   - description   - attachments   - items   - schedule_status  The following conditions will _not_ change `modified_at`:  - moving to a new container (project, portfolio, etc) - comments being added to the task (but the stories they generate   _will_ affect `modified_at`)  # noqa: E501

        :param modified_at: The modified_at of this TaskRequest.  # noqa: E501
        :type: datetime
        """

        self._modified_at = modified_at

    @property
    def notes(self):
        """Gets the notes of this TaskRequest.  # noqa: E501

        Free-form textual information associated with the task (i.e. its description).  # noqa: E501

        :return: The notes of this TaskRequest.  # noqa: E501
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """Sets the notes of this TaskRequest.

        Free-form textual information associated with the task (i.e. its description).  # noqa: E501

        :param notes: The notes of this TaskRequest.  # noqa: E501
        :type: str
        """

        self._notes = notes

    @property
    def num_hearts(self):
        """Gets the num_hearts of this TaskRequest.  # noqa: E501

        *Deprecated - please use likes instead* The number of users who have hearted this task.  # noqa: E501

        :return: The num_hearts of this TaskRequest.  # noqa: E501
        :rtype: int
        """
        return self._num_hearts

    @num_hearts.setter
    def num_hearts(self, num_hearts):
        """Sets the num_hearts of this TaskRequest.

        *Deprecated - please use likes instead* The number of users who have hearted this task.  # noqa: E501

        :param num_hearts: The num_hearts of this TaskRequest.  # noqa: E501
        :type: int
        """

        self._num_hearts = num_hearts

    @property
    def num_likes(self):
        """Gets the num_likes of this TaskRequest.  # noqa: E501

        The number of users who have liked this task.  # noqa: E501

        :return: The num_likes of this TaskRequest.  # noqa: E501
        :rtype: int
        """
        return self._num_likes

    @num_likes.setter
    def num_likes(self, num_likes):
        """Sets the num_likes of this TaskRequest.

        The number of users who have liked this task.  # noqa: E501

        :param num_likes: The num_likes of this TaskRequest.  # noqa: E501
        :type: int
        """

        self._num_likes = num_likes

    @property
    def num_subtasks(self):
        """Gets the num_subtasks of this TaskRequest.  # noqa: E501

        [Opt In](/docs/inputoutput-options). The number of subtasks on this task.   # noqa: E501

        :return: The num_subtasks of this TaskRequest.  # noqa: E501
        :rtype: int
        """
        return self._num_subtasks

    @num_subtasks.setter
    def num_subtasks(self, num_subtasks):
        """Sets the num_subtasks of this TaskRequest.

        [Opt In](/docs/inputoutput-options). The number of subtasks on this task.   # noqa: E501

        :param num_subtasks: The num_subtasks of this TaskRequest.  # noqa: E501
        :type: int
        """

        self._num_subtasks = num_subtasks

    @property
    def start_at(self):
        """Gets the start_at of this TaskRequest.  # noqa: E501

        Date and time on which work begins for the task, or null if the task has no start time. This takes an ISO 8601 date string in UTC and should not be used together with `start_on`. *Note: `due_at` must be present in the request when setting or unsetting the `start_at` parameter.*  # noqa: E501

        :return: The start_at of this TaskRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._start_at

    @start_at.setter
    def start_at(self, start_at):
        """Sets the start_at of this TaskRequest.

        Date and time on which work begins for the task, or null if the task has no start time. This takes an ISO 8601 date string in UTC and should not be used together with `start_on`. *Note: `due_at` must be present in the request when setting or unsetting the `start_at` parameter.*  # noqa: E501

        :param start_at: The start_at of this TaskRequest.  # noqa: E501
        :type: datetime
        """

        self._start_at = start_at

    @property
    def start_on(self):
        """Gets the start_on of this TaskRequest.  # noqa: E501

        The day on which work begins for the task , or null if the task has no start date. This takes a date with `YYYY-MM-DD` format and should not be used together with `start_at`. *Note: `due_on` or `due_at` must be present in the request when setting or unsetting the `start_on` parameter.*  # noqa: E501

        :return: The start_on of this TaskRequest.  # noqa: E501
        :rtype: date
        """
        return self._start_on

    @start_on.setter
    def start_on(self, start_on):
        """Sets the start_on of this TaskRequest.

        The day on which work begins for the task , or null if the task has no start date. This takes a date with `YYYY-MM-DD` format and should not be used together with `start_at`. *Note: `due_on` or `due_at` must be present in the request when setting or unsetting the `start_on` parameter.*  # noqa: E501

        :param start_on: The start_on of this TaskRequest.  # noqa: E501
        :type: date
        """

        self._start_on = start_on

    @property
    def actual_time_minutes(self):
        """Gets the actual_time_minutes of this TaskRequest.  # noqa: E501

        This value represents the sum of all the Time Tracking entries in the Actual Time field on a given Task. It is represented as a nullable long value.  # noqa: E501

        :return: The actual_time_minutes of this TaskRequest.  # noqa: E501
        :rtype: float
        """
        return self._actual_time_minutes

    @actual_time_minutes.setter
    def actual_time_minutes(self, actual_time_minutes):
        """Sets the actual_time_minutes of this TaskRequest.

        This value represents the sum of all the Time Tracking entries in the Actual Time field on a given Task. It is represented as a nullable long value.  # noqa: E501

        :param actual_time_minutes: The actual_time_minutes of this TaskRequest.  # noqa: E501
        :type: float
        """

        self._actual_time_minutes = actual_time_minutes

    @property
    def assignee(self):
        """Gets the assignee of this TaskRequest.  # noqa: E501

        Gid of a user.  # noqa: E501

        :return: The assignee of this TaskRequest.  # noqa: E501
        :rtype: str
        """
        return self._assignee

    @assignee.setter
    def assignee(self, assignee):
        """Sets the assignee of this TaskRequest.

        Gid of a user.  # noqa: E501

        :param assignee: The assignee of this TaskRequest.  # noqa: E501
        :type: str
        """

        self._assignee = assignee

    @property
    def assignee_section(self):
        """Gets the assignee_section of this TaskRequest.  # noqa: E501

        The *assignee section* is a subdivision of a project that groups tasks together in the assignee's \"My Tasks\" list. It can either be a header above a list of tasks in a list view or a column in a board view of \"My Tasks.\" The `assignee_section` property will be returned in the response only if the request was sent by the user who is the assignee of the task. Note that you can only write to `assignee_section` with the gid of an existing section visible in the user's \"My Tasks\" list.  # noqa: E501

        :return: The assignee_section of this TaskRequest.  # noqa: E501
        :rtype: str
        """
        return self._assignee_section

    @assignee_section.setter
    def assignee_section(self, assignee_section):
        """Sets the assignee_section of this TaskRequest.

        The *assignee section* is a subdivision of a project that groups tasks together in the assignee's \"My Tasks\" list. It can either be a header above a list of tasks in a list view or a column in a board view of \"My Tasks.\" The `assignee_section` property will be returned in the response only if the request was sent by the user who is the assignee of the task. Note that you can only write to `assignee_section` with the gid of an existing section visible in the user's \"My Tasks\" list.  # noqa: E501

        :param assignee_section: The assignee_section of this TaskRequest.  # noqa: E501
        :type: str
        """

        self._assignee_section = assignee_section

    @property
    def custom_fields(self):
        """Gets the custom_fields of this TaskRequest.  # noqa: E501

        An object where each key is a Custom Field GID and each value is an enum GID, string, number, object, or array.  # noqa: E501

        :return: The custom_fields of this TaskRequest.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._custom_fields

    @custom_fields.setter
    def custom_fields(self, custom_fields):
        """Sets the custom_fields of this TaskRequest.

        An object where each key is a Custom Field GID and each value is an enum GID, string, number, object, or array.  # noqa: E501

        :param custom_fields: The custom_fields of this TaskRequest.  # noqa: E501
        :type: dict(str, str)
        """

        self._custom_fields = custom_fields

    @property
    def followers(self):
        """Gets the followers of this TaskRequest.  # noqa: E501

        *Create-Only* An array of strings identifying users. These can either be the string \"me\", an email, or the gid of a user. In order to change followers on an existing task use `addFollowers` and `removeFollowers`.  # noqa: E501

        :return: The followers of this TaskRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._followers

    @followers.setter
    def followers(self, followers):
        """Sets the followers of this TaskRequest.

        *Create-Only* An array of strings identifying users. These can either be the string \"me\", an email, or the gid of a user. In order to change followers on an existing task use `addFollowers` and `removeFollowers`.  # noqa: E501

        :param followers: The followers of this TaskRequest.  # noqa: E501
        :type: list[str]
        """

        self._followers = followers

    @property
    def parent(self):
        """Gets the parent of this TaskRequest.  # noqa: E501

        Gid of a task.  # noqa: E501

        :return: The parent of this TaskRequest.  # noqa: E501
        :rtype: str
        """
        return self._parent

    @parent.setter
    def parent(self, parent):
        """Sets the parent of this TaskRequest.

        Gid of a task.  # noqa: E501

        :param parent: The parent of this TaskRequest.  # noqa: E501
        :type: str
        """

        self._parent = parent

    @property
    def projects(self):
        """Gets the projects of this TaskRequest.  # noqa: E501

        *Create-Only* Array of project gids. In order to change projects on an existing task use `addProject` and `removeProject`.  # noqa: E501

        :return: The projects of this TaskRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._projects

    @projects.setter
    def projects(self, projects):
        """Sets the projects of this TaskRequest.

        *Create-Only* Array of project gids. In order to change projects on an existing task use `addProject` and `removeProject`.  # noqa: E501

        :param projects: The projects of this TaskRequest.  # noqa: E501
        :type: list[str]
        """

        self._projects = projects

    @property
    def tags(self):
        """Gets the tags of this TaskRequest.  # noqa: E501

        *Create-Only* Array of tag gids. In order to change tags on an existing task use `addTag` and `removeTag`.  # noqa: E501

        :return: The tags of this TaskRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this TaskRequest.

        *Create-Only* Array of tag gids. In order to change tags on an existing task use `addTag` and `removeTag`.  # noqa: E501

        :param tags: The tags of this TaskRequest.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def workspace(self):
        """Gets the workspace of this TaskRequest.  # noqa: E501

        Gid of a workspace.  # noqa: E501

        :return: The workspace of this TaskRequest.  # noqa: E501
        :rtype: str
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        """Sets the workspace of this TaskRequest.

        Gid of a workspace.  # noqa: E501

        :param workspace: The workspace of this TaskRequest.  # noqa: E501
        :type: str
        """

        self._workspace = workspace

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TaskRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TaskRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class WebhookFilter(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'resource_type': 'str',
        'resource_subtype': 'str',
        'action': 'str',
        'fields': 'list[str]'
    }

    attribute_map = {
        'resource_type': 'resource_type',
        'resource_subtype': 'resource_subtype',
        'action': 'action',
        'fields': 'fields'
    }

    def __init__(self, resource_type=None, resource_subtype=None, action=None, fields=None):  # noqa: E501
        """WebhookFilter - a model defined in Swagger"""  # noqa: E501
        self._resource_type = None
        self._resource_subtype = None
        self._action = None
        self._fields = None
        self.discriminator = None
        if resource_type is not None:
            self.resource_type = resource_type
        if resource_subtype is not None:
            self.resource_subtype = resource_subtype
        if action is not None:
            self.action = action
        if fields is not None:
            self.fields = fields

    @property
    def resource_type(self):
        """Gets the resource_type of this WebhookFilter.  # noqa: E501

        The type of the resource which created the event when modified; for example, to filter to changes on regular tasks this field should be set to `task`.  # noqa: E501

        :return: The resource_type of this WebhookFilter.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this WebhookFilter.

        The type of the resource which created the event when modified; for example, to filter to changes on regular tasks this field should be set to `task`.  # noqa: E501

        :param resource_type: The resource_type of this WebhookFilter.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def resource_subtype(self):
        """Gets the resource_subtype of this WebhookFilter.  # noqa: E501

        The resource subtype of the resource that the filter applies to. This should be set to the same value as is returned on the `resource_subtype` field on the resources themselves.  # noqa: E501

        :return: The resource_subtype of this WebhookFilter.  # noqa: E501
        :rtype: str
        """
        return self._resource_subtype

    @resource_subtype.setter
    def resource_subtype(self, resource_subtype):
        """Sets the resource_subtype of this WebhookFilter.

        The resource subtype of the resource that the filter applies to. This should be set to the same value as is returned on the `resource_subtype` field on the resources themselves.  # noqa: E501

        :param resource_subtype: The resource_subtype of this WebhookFilter.  # noqa: E501
        :type: str
        """

        self._resource_subtype = resource_subtype

    @property
    def action(self):
        """Gets the action of this WebhookFilter.  # noqa: E501

        The type of change on the **resource** to pass through the filter. For more information refer to `Event.action` in the [event](/reference/events) schema. This can be one of `changed`, `added`, `removed`, `deleted`, and `undeleted` depending on the nature of what has occurred on the resource.  # noqa: E501

        :return: The action of this WebhookFilter.  # noqa: E501
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this WebhookFilter.

        The type of change on the **resource** to pass through the filter. For more information refer to `Event.action` in the [event](/reference/events) schema. This can be one of `changed`, `added`, `removed`, `deleted`, and `undeleted` depending on the nature of what has occurred on the resource.  # noqa: E501

        :param action: The action of this WebhookFilter.  # noqa: E501
        :type: str
        """

        self._action = action

    @property
    def fields(self):
        """Gets the fields of this WebhookFilter.  # noqa: E501

        *Conditional.* A whitelist of fields for events which will pass the filter when the resource is changed. These can be any combination of the fields on the resources themselves. This field is only valid for `action` of type `changed`  # noqa: E501

        :return: The fields of this WebhookFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        """Sets the fields of this WebhookFilter.

        *Conditional.* A whitelist of fields for events which will pass the filter when the resource is changed. These can be any combination of the fields on the resources themselves. This field is only valid for `action` of type `changed`  # noqa: E501

        :param fields: The fields of this WebhookFilter.  # noqa: E501
        :type: list[str]
        """

        self._fields = fields

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WebhookFilter, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhookFilter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class StoryCompact(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'gid': 'str',
        'resource_type': 'str',
        'created_at': 'datetime',
        'created_by': 'CustomFieldResponsePeopleValue',
        'resource_subtype': 'str',
        'text': 'str'
    }

    attribute_map = {
        'gid': 'gid',
        'resource_type': 'resource_type',
        'created_at': 'created_at',
        'created_by': 'created_by',
        'resource_subtype': 'resource_subtype',
        'text': 'text'
    }

    def __init__(self, gid=None, resource_type=None, created_at=None, created_by=None, resource_subtype=None, text=None):  # noqa: E501
        """StoryCompact - a model defined in Swagger"""  # noqa: E501
        self._gid = None
        self._resource_type = None
        self._created_at = None
        self._created_by = None
        self._resource_subtype = None
        self._text = None
        self.discriminator = None
        if gid is not None:
            self.gid = gid
        if resource_type is not None:
            self.resource_type = resource_type
        if created_at is not None:
            self.created_at = created_at
        if created_by is not None:
            self.created_by = created_by
        if resource_subtype is not None:
            self.resource_subtype = resource_subtype
        if text is not None:
            self.text = text

    @property
    def gid(self):
        """Gets the gid of this StoryCompact.  # noqa: E501

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :return: The gid of this StoryCompact.  # noqa: E501
        :rtype: str
        """
        return self._gid

    @gid.setter
    def gid(self, gid):
        """Sets the gid of this StoryCompact.

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :param gid: The gid of this StoryCompact.  # noqa: E501
        :type: str
        """

        self._gid = gid

    @property
    def resource_type(self):
        """Gets the resource_type of this StoryCompact.  # noqa: E501

        The base type of this resource.  # noqa: E501

        :return: The resource_type of this StoryCompact.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this StoryCompact.

        The base type of this resource.  # noqa: E501

        :param resource_type: The resource_type of this StoryCompact.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def created_at(self):
        """Gets the created_at of this StoryCompact.  # noqa: E501

        The time at which this resource was created.  # noqa: E501

        :return: The created_at of this StoryCompact.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this StoryCompact.

        The time at which this resource was created.  # noqa: E501

        :param created_at: The created_at of this StoryCompact.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def created_by(self):
        """Gets the created_by of this StoryCompact.  # noqa: E501


        :return: The created_by of this StoryCompact.  # noqa: E501
        :rtype: CustomFieldResponsePeopleValue
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this StoryCompact.


        :param created_by: The created_by of this StoryCompact.  # noqa: E501
        :type: CustomFieldResponsePeopleValue
        """

        self._created_by = created_by

    @property
    def resource_subtype(self):
        """Gets the resource_subtype of this StoryCompact.  # noqa: E501

        The subtype of this resource. Different subtypes retain many of the same fields and behavior, but may render differently in Asana or represent resources with different semantic meaning.  # noqa: E501

        :return: The resource_subtype of this StoryCompact.  # noqa: E501
        :rtype: str
        """
        return self._resource_subtype

    @resource_subtype.setter
    def resource_subtype(self, resource_subtype):
        """Sets the resource_subtype of this StoryCompact.

        The subtype of this resource. Different subtypes retain many of the same fields and behavior, but may render differently in Asana or represent resources with different semantic meaning.  # noqa: E501

        :param resource_subtype: The resource_subtype of this StoryCompact.  # noqa: E501
        :type: str
        """

        self._resource_subtype = resource_subtype

    @property
    def text(self):
        """Gets the text of this StoryCompact.  # noqa: E501

        *Create-only*. Human-readable text for the story or comment. This will not include the name of the creator. *Note: This is not guaranteed to be stable for a given type of story. For example, text for a reassignment may not always say “assigned to …” as the text for a story can both be edited and change based on the language settings of the user making the request.* Use the `resource_subtype` property to discover the action that created the story.  # noqa: E501

        :return: The text of this StoryCompact.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this StoryCompact.

        *Create-only*. Human-readable text for the story or comment. This will not include the name of the creator. *Note: This is not guaranteed to be stable for a given type of story. For example, text for a reassignment may not always say “assigned to …” as the text for a story can both be edited and change based on the language settings of the user making the request.* Use the `resource_subtype` property to discover the action that created the story.  # noqa: E501

        :param text: The text of this StoryCompact.  # noqa: E501
        :type: str
        """

        self._text = text

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StoryCompact, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StoryCompact):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AttachmentResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'gid': 'str',
        'resource_type': 'str',
        'name': 'str',
        'resource_subtype': 'str',
        'created_at': 'datetime',
        'download_url': 'str',
        'permanent_url': 'str',
        'host': 'str',
        'parent': 'AttachmentResponseParent',
        'size': 'int',
        'view_url': 'str',
        'connected_to_app': 'bool'
    }

    attribute_map = {
        'gid': 'gid',
        'resource_type': 'resource_type',
        'name': 'name',
        'resource_subtype': 'resource_subtype',
        'created_at': 'created_at',
        'download_url': 'download_url',
        'permanent_url': 'permanent_url',
        'host': 'host',
        'parent': 'parent',
        'size': 'size',
        'view_url': 'view_url',
        'connected_to_app': 'connected_to_app'
    }

    def __init__(self, gid=None, resource_type=None, name=None, resource_subtype=None, created_at=None, download_url=None, permanent_url=None, host=None, parent=None, size=None, view_url=None, connected_to_app=None):  # noqa: E501
        """AttachmentResponse - a model defined in Swagger"""  # noqa: E501
        self._gid = None
        self._resource_type = None
        self._name = None
        self._resource_subtype = None
        self._created_at = None
        self._download_url = None
        self._permanent_url = None
        self._host = None
        self._parent = None
        self._size = None
        self._view_url = None
        self._connected_to_app = None
        self.discriminator = None
        if gid is not None:
            self.gid = gid
        if resource_type is not None:
            self.resource_type = resource_type
        if name is not None:
            self.name = name
        if resource_subtype is not None:
            self.resource_subtype = resource_subtype
        if created_at is not None:
            self.created_at = created_at
        if download_url is not None:
            self.download_url = download_url
        if permanent_url is not None:
            self.permanent_url = permanent_url
        if host is not None:
            self.host = host
        if parent is not None:
            self.parent = parent
        if size is not None:
            self.size = size
        if view_url is not None:
            self.view_url = view_url
        if connected_to_app is not None:
            self.connected_to_app = connected_to_app

    @property
    def gid(self):
        """Gets the gid of this AttachmentResponse.  # noqa: E501

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :return: The gid of this AttachmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._gid

    @gid.setter
    def gid(self, gid):
        """Sets the gid of this AttachmentResponse.

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :param gid: The gid of this AttachmentResponse.  # noqa: E501
        :type: str
        """

        self._gid = gid

    @property
    def resource_type(self):
        """Gets the resource_type of this AttachmentResponse.  # noqa: E501

        The base type of this resource.  # noqa: E501

        :return: The resource_type of this AttachmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this AttachmentResponse.

        The base type of this resource.  # noqa: E501

        :param resource_type: The resource_type of this AttachmentResponse.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def name(self):
        """Gets the name of this AttachmentResponse.  # noqa: E501

        The name of the file.  # noqa: E501

        :return: The name of this AttachmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AttachmentResponse.

        The name of the file.  # noqa: E501

        :param name: The name of this AttachmentResponse.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def resource_subtype(self):
        """Gets the resource_subtype of this AttachmentResponse.  # noqa: E501

        The service hosting the attachment. Valid values are `asana`, `dropbox`, `gdrive`, `onedrive`, `box`, `vimeo`, and `external`.  # noqa: E501

        :return: The resource_subtype of this AttachmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._resource_subtype

    @resource_subtype.setter
    def resource_subtype(self, resource_subtype):
        """Sets the resource_subtype of this AttachmentResponse.

        The service hosting the attachment. Valid values are `asana`, `dropbox`, `gdrive`, `onedrive`, `box`, `vimeo`, and `external`.  # noqa: E501

        :param resource_subtype: The resource_subtype of this AttachmentResponse.  # noqa: E501
        :type: str
        """

        self._resource_subtype = resource_subtype

    @property
    def created_at(self):
        """Gets the created_at of this AttachmentResponse.  # noqa: E501

        The time at which this resource was created.  # noqa: E501

        :return: The created_at of this AttachmentResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this AttachmentResponse.

        The time at which this resource was created.  # noqa: E501

        :param created_at: The created_at of this AttachmentResponse.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def download_url(self):
        """Gets the download_url of this AttachmentResponse.  # noqa: E501

        The URL containing the content of the attachment. *Note:* May be null if the attachment is hosted by [Box](https://www.box.com/) and will be null if the attachment is a Video Message hosted by [Vimeo](https://vimeo.com/). If present, this URL may only be valid for two minutes from the time of retrieval. You should avoid persisting this URL somewhere and just refresh it on demand to ensure you do not keep stale URLs.  # noqa: E501

        :return: The download_url of this AttachmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._download_url

    @download_url.setter
    def download_url(self, download_url):
        """Sets the download_url of this AttachmentResponse.

        The URL containing the content of the attachment. *Note:* May be null if the attachment is hosted by [Box](https://www.box.com/) and will be null if the attachment is a Video Message hosted by [Vimeo](https://vimeo.com/). If present, this URL may only be valid for two minutes from the time of retrieval. You should avoid persisting this URL somewhere and just refresh it on demand to ensure you do not keep stale URLs.  # noqa: E501

        :param download_url: The download_url of this AttachmentResponse.  # noqa: E501
        :type: str
        """

        self._download_url = download_url

    @property
    def permanent_url(self):
        """Gets the permanent_url of this AttachmentResponse.  # noqa: E501


        :return: The permanent_url of this AttachmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._permanent_url

    @permanent_url.setter
    def permanent_url(self, permanent_url):
        """Sets the permanent_url of this AttachmentResponse.


        :param permanent_url: The permanent_url of this AttachmentResponse.  # noqa: E501
        :type: str
        """

        self._permanent_url = permanent_url

    @property
    def host(self):
        """Gets the host of this AttachmentResponse.  # noqa: E501

        The service hosting the attachment. Valid values are `asana`, `dropbox`, `gdrive`, `box`, and `vimeo`.  # noqa: E501

        :return: The host of this AttachmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this AttachmentResponse.

        The service hosting the attachment. Valid values are `asana`, `dropbox`, `gdrive`, `box`, and `vimeo`.  # noqa: E501

        :param host: The host of this AttachmentResponse.  # noqa: E501
        :type: str
        """

        self._host = host

    @property
    def parent(self):
        """Gets the parent of this AttachmentResponse.  # noqa: E501


        :return: The parent of this AttachmentResponse.  # noqa: E501
        :rtype: AttachmentResponseParent
        """
        return self._parent

    @parent.setter
    def parent(self, parent):
        """Sets the parent of this AttachmentResponse.


        :param parent: The parent of this AttachmentResponse.  # noqa: E501
        :type: AttachmentResponseParent
        """

        self._parent = parent

    @property
    def size(self):
        """Gets the size of this AttachmentResponse.  # noqa: E501

        The size of the attachment in bytes. Only present when the `resource_subtype` is `asana`.  # noqa: E501

        :return: The size of this AttachmentResponse.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this AttachmentResponse.

        The size of the attachment in bytes. Only present when the `resource_subtype` is `asana`.  # noqa: E501

        :param size: The size of this AttachmentResponse.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def view_url(self):
        """Gets the view_url of this AttachmentResponse.  # noqa: E501

        The URL where the attachment can be viewed, which may be friendlier to users in a browser than just directing them to a raw file. May be null if no view URL exists for the service.  # noqa: E501

        :return: The view_url of this AttachmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._view_url

    @view_url.setter
    def view_url(self, view_url):
        """Sets the view_url of this AttachmentResponse.

        The URL where the attachment can be viewed, which may be friendlier to users in a browser than just directing them to a raw file. May be null if no view URL exists for the service.  # noqa: E501

        :param view_url: The view_url of this AttachmentResponse.  # noqa: E501
        :type: str
        """

        self._view_url = view_url

    @property
    def connected_to_app(self):
        """Gets the connected_to_app of this AttachmentResponse.  # noqa: E501

        Whether the attachment is connected to the app making the request for the purposes of showing an app components widget. Only present when the `resource_subtype` is `external` or `gdrive`.  # noqa: E501

        :return: The connected_to_app of this AttachmentResponse.  # noqa: E501
        :rtype: bool
        """
        return self._connected_to_app

    @connected_to_app.setter
    def connected_to_app(self, connected_to_app):
        """Sets the connected_to_app of this AttachmentResponse.

        Whether the attachment is connected to the app making the request for the purposes of showing an app components widget. Only present when the `resource_subtype` is `external` or `gdrive`.  # noqa: E501

        :param connected_to_app: The connected_to_app of this AttachmentResponse.  # noqa: E501
        :type: bool
        """

        self._connected_to_app = connected_to_app

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AttachmentResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AttachmentResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class EventResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'user': 'EventResponseUser',
        'resource': 'EventResponseResource',
        'type': 'str',
        'action': 'str',
        'parent': 'EventResponseParent',
        'created_at': 'datetime',
        'change': 'EventResponseChange'
    }

    attribute_map = {
        'user': 'user',
        'resource': 'resource',
        'type': 'type',
        'action': 'action',
        'parent': 'parent',
        'created_at': 'created_at',
        'change': 'change'
    }

    def __init__(self, user=None, resource=None, type=None, action=None, parent=None, created_at=None, change=None):  # noqa: E501
        """EventResponse - a model defined in Swagger"""  # noqa: E501
        self._user = None
        self._resource = None
        self._type = None
        self._action = None
        self._parent = None
        self._created_at = None
        self._change = None
        self.discriminator = None
        if user is not None:
            self.user = user
        if resource is not None:
            self.resource = resource
        if type is not None:
            self.type = type
        if action is not None:
            self.action = action
        if parent is not None:
            self.parent = parent
        if created_at is not None:
            self.created_at = created_at
        if change is not None:
            self.change = change

    @property
    def user(self):
        """Gets the user of this EventResponse.  # noqa: E501


        :return: The user of this EventResponse.  # noqa: E501
        :rtype: EventResponseUser
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this EventResponse.


        :param user: The user of this EventResponse.  # noqa: E501
        :type: EventResponseUser
        """

        self._user = user

    @property
    def resource(self):
        """Gets the resource of this EventResponse.  # noqa: E501


        :return: The resource of this EventResponse.  # noqa: E501
        :rtype: EventResponseResource
        """
        return self._resource

    @resource.setter
    def resource(self, resource):
        """Sets the resource of this EventResponse.


        :param resource: The resource of this EventResponse.  # noqa: E501
        :type: EventResponseResource
        """

        self._resource = resource

    @property
    def type(self):
        """Gets the type of this EventResponse.  # noqa: E501

        *Deprecated: Refer to the resource_type of the resource.* The type of the resource that generated the event.  # noqa: E501

        :return: The type of this EventResponse.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this EventResponse.

        *Deprecated: Refer to the resource_type of the resource.* The type of the resource that generated the event.  # noqa: E501

        :param type: The type of this EventResponse.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def action(self):
        """Gets the action of this EventResponse.  # noqa: E501

        The type of action taken on the **resource** that triggered the event.  This can be one of `changed`, `added`, `removed`, `deleted`, or `undeleted` depending on the nature of the event.  # noqa: E501

        :return: The action of this EventResponse.  # noqa: E501
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this EventResponse.

        The type of action taken on the **resource** that triggered the event.  This can be one of `changed`, `added`, `removed`, `deleted`, or `undeleted` depending on the nature of the event.  # noqa: E501

        :param action: The action of this EventResponse.  # noqa: E501
        :type: str
        """

        self._action = action

    @property
    def parent(self):
        """Gets the parent of this EventResponse.  # noqa: E501


        :return: The parent of this EventResponse.  # noqa: E501
        :rtype: EventResponseParent
        """
        return self._parent

    @parent.setter
    def parent(self, parent):
        """Sets the parent of this EventResponse.


        :param parent: The parent of this EventResponse.  # noqa: E501
        :type: EventResponseParent
        """

        self._parent = parent

    @property
    def created_at(self):
        """Gets the created_at of this EventResponse.  # noqa: E501

        The timestamp when the event occurred.  # noqa: E501

        :return: The created_at of this EventResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this EventResponse.

        The timestamp when the event occurred.  # noqa: E501

        :param created_at: The created_at of this EventResponse.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def change(self):
        """Gets the change of this EventResponse.  # noqa: E501


        :return: The change of this EventResponse.  # noqa: E501
        :rtype: EventResponseChange
        """
        return self._change

    @change.setter
    def change(self, change):
        """Sets the change of this EventResponse.


        :param change: The change of this EventResponse.  # noqa: E501
        :type: EventResponseChange
        """

        self._change = change

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EventResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EventResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
